summaryrefslogtreecommitdiffstats
path: root/media/cdm/aes_decryptor.h
diff options
context:
space:
mode:
authorjrummell@chromium.org <jrummell@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-10 07:25:54 +0000
committerjrummell@chromium.org <jrummell@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-10 07:25:54 +0000
commita267ff14ffc271d52522affde71803bd29bca3e3 (patch)
treec7db4579831244d8071ee8d9205ce571d39d371c /media/cdm/aes_decryptor.h
parent6718537577fc2e16f92beecd8163c3cad95c0ca6 (diff)
downloadchromium_src-a267ff14ffc271d52522affde71803bd29bca3e3.zip
chromium_src-a267ff14ffc271d52522affde71803bd29bca3e3.tar.gz
chromium_src-a267ff14ffc271d52522affde71803bd29bca3e3.tar.bz2
Rename EME WD call parameters
Rename parameters on EME WD calls to be consistent. BUG=224786 TEST=compiles Review URL: https://codereview.chromium.org/105383002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@239698 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'media/cdm/aes_decryptor.h')
-rw-r--r--media/cdm/aes_decryptor.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/media/cdm/aes_decryptor.h b/media/cdm/aes_decryptor.h
index 8e03106..35b1488 100644
--- a/media/cdm/aes_decryptor.h
+++ b/media/cdm/aes_decryptor.h
@@ -35,14 +35,14 @@ class MEDIA_EXPORT AesDecryptor : public MediaKeys, public Decryptor {
virtual ~AesDecryptor();
// MediaKeys implementation.
- virtual bool CreateSession(uint32 reference_id,
+ virtual bool CreateSession(uint32 session_id,
const std::string& type,
const uint8* init_data,
int init_data_length) OVERRIDE;
- virtual void UpdateSession(uint32 reference_id,
+ virtual void UpdateSession(uint32 session_id,
const uint8* response,
int response_length) OVERRIDE;
- virtual void ReleaseSession(uint32 reference_id) OVERRIDE;
+ virtual void ReleaseSession(uint32 session_id) OVERRIDE;
virtual Decryptor* GetDecryptor() OVERRIDE;
// Decryptor implementation.
@@ -115,10 +115,9 @@ class MEDIA_EXPORT AesDecryptor : public MediaKeys, public Decryptor {
KeyMap key_map_; // Protected by the |key_map_lock_|.
mutable base::Lock key_map_lock_; // Protects the |key_map_|.
- // Make session ID unique per renderer by making it static.
- // TODO(xhwang): Make session ID more strictly defined if needed:
- // https://www.w3.org/Bugs/Public/show_bug.cgi?id=16739#c0
- static uint32 next_session_id_;
+ // Make web session ID unique per renderer by making it static. Web session
+ // IDs seen by the app will be "1", "2", etc.
+ static uint32 next_web_session_id_;
NewKeyCB new_audio_key_cb_;
NewKeyCB new_video_key_cb_;